package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!`````ID$"#0```!LL@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(U*T`
M`-2M```%`````!````$```#XK@``^#X%"/@^!0@P`@``G!(```8`````$```
M`@````2O```$/P4(!#\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&0PGP``,!\%"#`?!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^*X`
M`/@^!0CX/@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`PC[A!J"UGV8U70^VQG0K.BBIV2HE````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````X`(`````````````$@```(8#
M`````````````!(````D`@`````````````2````$0``````````````(```
M`/0#`````````````!(```!W`P`````````````2````/0$`````````````
M$@```/L"`````````````!(```#3```````````````2````YP(`````````
M````$@```*\``````````````!(````X`0`````````````2````G@(`````
M````````$@```#0#`````````````!(```"O`@`````````````2````H0$`
M````````````$@```$0#`````````````!(````[`P`````````````2````
M80$`````````````$@```.$``````````````!(```#K`0`````````````2
M````B`$`````````````$@```&T"`````````````!(````<`@``````````
M```2````RP(`````````````$@```-@!`````````````!(```"\`@``````
M```````2````Y`$`````````````$@```&\!`````````````!(```!+`P``
M```````````2````+0``````````````(````'\"`````````````!(```!8
M`P`````````````2````>```````````````$@```-D"`````````````!(`
M``"-`P`````````````2````%0(`````````````$@````\!````````````
M`!(```"^```````````````2````E@$`````````````$@```+8"````````
M`````!(```",`@`````````````2````/0(`````````````$@```,0"````
M`````````!(```!J```````````````2````0@$`````````````$@````(#
M`````````````!(```#-`0`````````````2````'`$`````````````$@``
M`'\#`````````````!(```#2`@`````````````2````KP$`````````````
M$@```#P``````````````"````#S```````````````2````?P$`````````
M````$@```%\#`````````````!(```#M`@`````````````2````AP``````
M````````$@```%```````````````"````"$`@`````````````2````(P,`
M````````````$@```"D"`````````````!(````0`P`````````````2````
M3@(`````````````$@```)4"`````````````!(````;`P`````````````2
M````:0,`````````````$@```$X!``!0E00(`````!(```!L!```Z-\$"`0`
M```1``\`(@0``&#.!`@W#```$@`-`',$``#0R@0(MP$``!(`#0#+`P``U-\$
M"``````2``X`H0,``$!!!0@$````(0`9`-$#``#@QP0(!0```!(`#0!2!```
M8-\$"&$````2``T`G@````"6!`@`````$@```"T!``!(004(!````!$`&0`O
M!```&$$%"``````0`!@`+0,``$1!!0@$````$0`9`#$$```8004(`````"``
M&`"@`P``0$$%"`0````A`!D`P0,``-#?!`@"````$@`-`&($```D004(!```
M`!$`&`"(!```\,<$"+P!```2``T``@$``$Q!!0@!````$0`9`)\#``!`004(
M!````!$`&0":`P``X)8$""("```2``T`IP0``)#,!`AI````$@`-`.(#````
MS00()````!(`#0#]`P``<-X$"&D````2``T`L`,``"A!!0@`````$``9`+P#
M``"4404(`````!``&0!>`@``[-\$"`0````1``\`T00``*#:!`C.`P``$@`-
M`#P$```@QP0(L0```!(`#0`U!````ID$"``````2``T`O0$``#"3!`@`````
M$@```!8$``#@R00(Z````!(`#0"I`P``*$$%"``````0`!@`"00``+#)!`@B
M````$@`-`+4$``#@W@0(.````!(`#0"`!```H,8$""<````2``T`]@$``%!!
M!0@3````$0`9`)4$```PS00()@$``!(`#0""!```=)($"``````2``L``&QI
M8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R
M7W!L`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT
M``````(``@`#`````@`"``(``@````(```````0``@`"`````@`"````````
M````!0`&``(````"``(````'`````@`"`````@`"``8``````````@`"``,`
M`@``````!P```````@`"````````````"``'```````"``@``P`(``,``@`"
M``<````!``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!`````0`"``4"```0
M````,````!)I:0T```8`YP0``!`````0:6D-```#`/$$`````````0`%`%0"
M```0`````````!)I:0T```@`YP0``!````!T&6D)```'`/L$```0````<AEI
M"0``!0`'!0``$````!1I:0T```0`$P4``!`````0:6D-```"`/$$````````
M_#\%"`8?``!`004(!58``$1!!0@%3P``2$$%"`5-``!,004(!54``%!!!0@%
M9P``#$`%"`<!```00`4(!P(``!1`!0@'`P``&$`%"`<%```<0`4(!P8``"!`
M!0@'!P``)$`%"`<(```H0`4(!PD``"Q`!0@'80``,$`%"`<*```T0`4(!PL`
M`#A`!0@'#```/$`%"`<-``!`0`4(!PX``$1`!0@'#P``2$`%"`<0``!,0`4(
M!Q$``%!`!0@'$@``5$`%"`<3``!80`4(!Q0``%Q`!0@'%0``8$`%"`<6``!D
M0`4(!Q<``&A`!0@'&```;$`%"`<9``!P0`4(!QH``'1`!0@'&P``>$`%"`<<
M``!\0`4(!QT``(!`!0@''@``A$`%"`<?``"(0`4(!R```(Q`!0@'(0``D$`%
M"`<B``"40`4(!R,``)A`!0@')```G$`%"`<E``"@0`4(!R8``*1`!0@')P``
MJ$`%"`<H``"L0`4(!RD``+!`!0@'*@``M$`%"`=$``"X0`4(!RL``+Q`!0@'
M+```P$`%"`<M``#$0`4(!RX``,A`!0@'+P``S$`%"`<P``#00`4(!S$``-1`
M!0@',@``V$`%"`<S``#<0`4(!S0``.!`!0@'3```Y$`%"`<V``#H0`4(!S<`
M`.Q`!0@'.```\$`%"`<Y``#T0`4(!SH``/A`!0@'/```_$`%"`<]````004(
M!SX```1!!0@'/P``"$$%"`=````,004(!T$``!!!!0@'0@``%$$%"`=#``!3
M@^P(Z+,&``"!PX.M``"+@_S___^%P'0%Z/X!``"#Q`A;PP```````````/\U
M!$`%"/\E"$`%"`````#_)0Q`!0AH`````.G@_____R400`4(:`@```#IT/__
M__\E%$`%"&@0````Z<#_____)1A`!0AH&````.FP_____R4<0`4(:"````#I
MH/____\E($`%"&@H````Z9#_____)21`!0AH,````.F`_____R4H0`4(:#@`
M``#I</____\E+$`%"&A`````Z6#_____)3!`!0AH2````.E0_____R4T0`4(
M:%````#I0/____\E.$`%"&A8````Z3#_____)3Q`!0AH8````.D@_____R5`
M0`4(:&@```#I$/____\E1$`%"&AP````Z0#_____)4A`!0AH>````.GP_O__
M_R5,0`4(:(````#IX/[___\E4$`%"&B(````Z=#^____)51`!0AHD````.G`
M_O___R580`4(:)@```#IL/[___\E7$`%"&B@````Z:#^____)6!`!0AHJ```
M`.F0_O___R5D0`4(:+````#I@/[___\E:$`%"&BX````Z7#^____)6Q`!0AH
MP````.E@_O___R5P0`4(:,@```#I4/[___\E=$`%"&C0````Z4#^____)7A`
M!0AHV````.DP_O___R5\0`4(:.````#I(/[___\E@$`%"&CH````Z1#^____
M)81`!0AH\````.D`_O___R6(0`4(:/@```#I\/W___\EC$`%"&@``0``Z>#]
M____)9!`!0AH"`$``.G0_?___R640`4(:!`!``#IP/W___\EF$`%"&@8`0``
MZ;#]____)9Q`!0AH(`$``.F@_?___R6@0`4(:"@!``#ID/W___\EI$`%"&@P
M`0``Z8#]____):A`!0AH.`$``.EP_?___R6L0`4(:$`!``#I8/W___\EL$`%
M"&A(`0``Z5#]____);1`!0AH4`$``.E`_?___R6X0`4(:%@!``#I,/W___\E
MO$`%"&A@`0``Z2#]____)<!`!0AH:`$``.D0_?___R7$0`4(:'`!``#I`/W_
M__\ER$`%"&AX`0``Z?#\____)<Q`!0AH@`$``.G@_/___R700`4(:(@!``#I
MT/S___\EU$`%"&B0`0``Z<#\____)=A`!0AHF`$``.FP_/___R7<0`4(:*`!
M``#IH/S___\EX$`%"&BH`0``Z9#\____)>1`!0AHL`$``.F`_/___R7H0`4(
M:+@!``#I</S___\E[$`%"&C``0``Z6#\____)?!`!0AHR`$``.E0_/___R7T
M0`4(:-`!``#I0/S___\E^$`%"&C8`0``Z3#\____)?Q`!0AHX`$``.D@_/__
M_R4`004(:.@!``#I$/S___\E!$$%"&CP`0``Z0#\____)0A!!0AH^`$``.GP
M^____R4,004(:``"``#IX/O___\E$$$%"&@(`@``Z=#[____)11!!0AH$`(`
M`.G`^___C4PD!(/D\/]Q_%6)Y59348G+@^Q`BT$$B474BT$(B4709:$4````
MB47D,<"-1=!0C4744%'HIOW__X/$#&A0E00(:%"5!`AH`)8$".CO1P``@\00
M@#U,004(`'4QZ*[\__^%P*.0404(#X2I`0``@^P,4.CX^___6?\U2$$%".@<
M____@\00QH`=!0```(/L#/\U2$$%".@$____@(C.`@```EK_-4A!!0CH\?[_
M_X"(S@(```&+`X/$$,=%Q`````"#P`6)1<#?;<#8!20?!0C=!2@?!0C9R=_I
MW=@/AP,!``"#[`S!X`)0Z''\__^+==2+&X/$$*.$404(QP6(404(!````(L6
M@_L!QT`$R^$$",=`#,[A!`B)$(L5)$$%"(E0"+H!````?A.0C70F`(L,EHE,
MD`R#P@$YVG7R@^P,QT28#`````"#PP-J`%!3:-#&!`C_-9!1!0CH</W__X/$
M((7`B<-T48/L#/\UD%$%".A)^___C57@N(_@!`CHW"8``(/$$(7`=$2#[`S_
M-9!1!0CHY_K__^@"_?__@\00B=B+=>1E,S44````=62-9?196UY=C6'\PX/L
M#/\UD%$%".AX_?__@\00B</KFJ&,404(A<!T'X/L#%#HKT4``(/$$.NE4%!H
M4$$%"&@_X`0(Z#G\__^-5>"X1.`$".A<)@``A<"CC%$%"`^$>O___^O%Z'CZ
M__^#[`QJ`>B>^___,>U>B>&#Y/!05%)HT-\$"&A@WP0(459HX)8$".B]^___
M]&:09I!FD&:09I!FD(L<),-FD&:09I!FD&:09I"X*T$%""TH004(@_@&=AJX
M`````(7`=!%5B>6#[!1H*$$%"/_0@\00R?/#D(UT)@"X*$$%""TH004(P?@"
MB<+!ZA\!T-'X=!NZ`````(72=!)5B>6#[!!0:"A!!0C_TH/$$,GSPXUT)@"-
MO"<`````@#UC004(`'4358GE@^P(Z'S____&!6-!!0@!R?/#9I"X`#\%"(L0
MA=)U!>N3C78`N@````"%TG3R58GE@^P44/_2@\00R>EU____9I!FD)!55S'M
M5E.![`P#``")1"1H@\`XB70D"&6+%10```")E"3\`@``,=*)!"2)?"0,9I"+
M!"3'1.Q\`````,>$[(0`````````BU2H!(L$J(G!B<:)U\'A",'F&('A``#_
M``GQB<8/K-8(@>8`_P``"<Z)P8G0#ZS1&#'2@>'_````"?&)_HE,['B)^<'F
M&,'A"('A``#_``G.B?D/K-$(#ZS0&('A`/\```GQ)?\````)R(F$[(````"#
MQ0*#_1`/A6W___^-A"3@````C90DX`(``(VT)@````"+6-B+2-R#P`@S6/@S
M2/PS6*`S2*0S6)`S2)3'0!0`````B<^)V8G>#ZSY'XG[B0PDB?'!ZQ\!\0L,
M)(E<)`2)2!`YT'6ZBT0D:(M(#(M8$(M0"(MP%(LXBV@$B4PD!(M(&(E<)`B+
M6!R)%"2)="0,B4PD,(M(((E<)#2+6"2)^(E$)"B);"0LB4PD4`-,)'B)7"14
M$UPD?(G:B<N!PYEY@EJ)UH/6`(G9P>`%B?.)_HG/#ZSN&S'2B=T)QHL$)`'W
MB7PD$(M\)`@1U8G&B6PD%/?6B?.+="0P(?.)_HM\)!`AQHET)!B+;"08"=T!
M[XE\)"")?"00BP0DBU0D!(M,)"C'1"04`````,=$)!P`````QT0D/`````")
MQXG&QT0D1``````/K-<"P>8>BU0D%,=$)"0`````B?V+?"0P"?4#O"2`````
MB<Z);"0X]]:+;"0XB?B+?"0H!9EY@EHC="0((<T)]8GIBVPD+`'!BT0D$(G+
MB?F)QL'@!0^LUAN+5"00"<8!\\'G'@^LZ0+WTHE<)!B)7"18B<V+3"0("?T#
MC"2(````B6PD0(ML)""!P9EY@EHC5"0X(VPD0(GHB=6+5"0<"<6+1"08`>F)
MRXG&P>`%#ZS6&PG&`?.+="00B5PD8(E<)""+?"04BU0D.(GQP>8>QT0D%```
M``#'1"1,`````,=$)#P`````#ZSY`HM\)!S'1"0<`````(G-"?4#E"20````
MB6PD2(ML)%B)T8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!
MZ8G+B<;!X`4/K-8;BU0D0`G&`?.+="08B5PD$(E<)%B)\<'F'@^L^0*+?"0D
MB<T)]0.4))@```");"0XBVPD8(G1BU0D(('!F7F"6B-L)#CWTB-4)$B)Z(G5
MBU0D%`G%BT0D$`'IB<N)QL'@!0^LUAL)Q@'SBW0D((E<)&")7"08B?'!YAX/
MK/D"B<T)]8EL)$"+5"1(`Y0DH````(ML)%B+?"04QT0D)`````#'1"1$````
M`,=$)$P`````QT0D%`````#'1"0\`````(G1BU0D$('!F7F"6B-L)$#WTB-4
M)#B)Z(G5BU0D'`G%BT0D&`'IB<N)QL'@!0^LUAN+5"0X"<8!\XMT)!")7"0@
MB5PD6(GQP>8>#ZSY`HM\)!R)S0GU`Y0DJ````(EL)$B+;"1@B=&+5"08@<&9
M>8):(VPD2/?2(U0D0(GHB=6+5"0D"<6+1"0@`>F)RXG&P>`%#ZS6&PG&`?.+
M="08B5PD8(E<)!")\<'F'@^L^0*)S0GUB6PD.(M4)$`#E"2P````BVPD6(M\
M)"3'1"0<`````,=$)$0`````QT0D)`````#'1"1,`````(G1BU0D(('!F7F"
M6B-L)#CWTB-4)$B)Z(G5BU0D%`G%BT0D$`'IB<N)QL'@!0^LUAN+5"1("<8!
M\XMT)"")7"08B5PD6(GQP>8>#ZSY`HM\)!2)S0GU`Y0DN````(EL)$"+;"1@
MB=&+5"00@<&9>8):(VPD0/?2(U0D.(GHB=6+5"0<"<6+1"08`>F)RXG&P>`%
M#ZS6&XM4)#@)Q@'SBW0D$(E<)&")7"0@B?'!YAX/K/D"B<T)]8EL)$@#E"3`
M````BVPD6(M\)!S'1"04`````,=$)#P`````QT0D'`````#'1"1$`````(G1
MBU0D&('!F7F"6B-L)$CWTB-4)$")Z(G5BU0D)`G%BT0D(`'IB<N)QL'@!0^L
MUAN+5"1`"<8!\XMT)!B)7"00B5PD6(GQP>8>#ZSY`HM\)"2)S0GU`Y0DR```
M`(EL)#B+;"1@B=&+5"0@@<&9>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00
M`>F)RXG&P>`%#ZS6&XM4)$@)Q@'SBW0D((E<)&")7"08B?'!YAX/K/D"B<T)
M]8EL)$`#E"30````BVPD6(M\)!3'1"0D`````,=$)$P`````QT0D%`````#'
M1"0\`````(G1BU0D$('!F7F"6B-L)$#WTB-4)#B)Z(G5BU0D'`G%BT0D&`'I
MB<N)QL'@!0^LUAN+5"0X"<8!\XMT)!")7"0@B5PD6(GQP>8>#ZSY`HM\)!R)
MS0GU`Y0DV````(EL)$B+;"1@B=&+5"08@<&9>8):(VPD2/?2(U0D0(GHB=6+
M5"0D"<6+1"0@`>F)RXG&P>`%#ZS6&XM4)$`)Q@'SBW0D&(E<)&")7"00B?'!
MYAX/K/D"B<T)]0.4).````");"0XB=&+5"0@BVPD6('!F7F"6B-L)#B+?"0D
MQT0D'`````#'1"1$`````/?2(U0D2,=$)"0`````QT0D3`````")Z(G5BU0D
M%`G%BT0D$`'IB<N)QL'@!0^LUAN+5"1("<8!\XMT)"")7"08B5PD6(GQP>8>
M#ZSY`HM\)!2)S0GU`Y0DZ````(EL)$"+;"1@B=&+5"00@<&9>8):(VPD0/?2
M(U0D.(GHB=6+5"0<"<6+1"08`>F)RXG&P>`%#ZS6&XM4)#@)Q@'SBW0D$(E<
M)&")7"0@B?'!YAX/K/D"B<T)]0.4)/````");"1(B=&+5"08@<&9>8):]](C
M5"1`BVPD6"-L)$B+?"0<QT0D%`````#'1"0\`````,=$)!P`````QT0D1```
M``")Z(G5BU0D)`G%BT0D(`'IB<N)QL'@!0^LUAN+5"1`"<8!\XMT)!B)7"00
MB5PD6(GQP>8>#ZSY`HM\)"2)S0GU`Y0D^````(EL)#B+;"1@B=&+5"0@@<&9
M>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00`>F)RXG&P>`%#ZS6&XM4)$@)
MQ@'SBW0D((E<)&")7"08B?'!YAX/K/D"B<T)]0.4)``!``");"1`B=&+5"00
M@<&9>8):]](C5"0XBVPD6"-L)$"+?"04QT0D)`````#'1"1,`````(GHB=6+
M5"0<"<6+1"08`>F)RXG&P>`%#ZS6&XM4)#@)Q@'SBW0D$(E<)"")7"18B?'!
MYAX/K/D"B<V+3"0\QT0D/``````)]0.4)`@!```3C"0,`0``B6PD2(ML)&")
MRXG1BU0D&('!F7F"6H/3`"-L)$@Q__?2(U0D0(GHB=6+5"0D"<6+1"0@`>D1
M^XM\)!S'1"0<`````(G&P>`%#ZS6&S'2"<:)\(G>B<L!PQ'6B5PD8(E<)#B)
M="1DBW0D&(M4)$")\<'F'@^L^0*)S0GUB6PD;(EL)!@#E"00`0``BW0D6(M$
M)#B+?"0DQT0D%`````")T8M4)""!P9EY@EHA[HML)&SWTB-4)$@)\HG&`=&+
M5"0\P>`%B<L/K-8;BU0D2`G&`?.+="0@B5PD$(E<)$")\<'F'@^L^0*)\(G.
M"<8#E"08`0``B70D((G0BU0D%`6AZ]EN,?6)[HML)&`Q]8GI`<&+1"00B<N)
MQL'@!8E$)$B+1"0XBVPD2`^LUAN+5"0\B<$)]0'KP>`>,?\/K-$"B=Z)7"1(
MBU0D&(G+BVPD0`G#`Y0D(`$``(E<)#B)T`6AZ]EN,UPD(#'=B>D!P8GP#ZSX
M&XE$)!B)\(ML)!C!X`6)1"1`"VPD0(M4)!"+1"0@QT0D'``````!Z8E,)!B)
M3"1`BTPD%`^LR@*+3"00B=6+E"0H`0``P>$>"<V+C"0L`0``@<*AZ]ENB6PD
M((/1`(G+B=$QT@'($=HS;"0XB40D$(E4)!2+5"1(BT0D&,=$)!0`````,>J)
MT8M4)!P#3"00#ZS0&XGRB40D$(M$)!B+;"00P>`%B40D2`ML)$B+1"0X`>G!
MYAX/K/H"B4PD$(E,)$B)U0GUB[0D,`$``(EL)#B!QJ'KV6X!\(MT)"`Q[HML
M)$`Q]8GI`<&+1"00BU0D%(G+B<;!X`6)1"1`BT0D&(ML)$`/K-8;BU0D'(G!
MQT0D'``````)]0'KP>`>,?\/K-$"B=Z)7"1`BY0D.`$``(G+"<.+1"0@B=V)
M7"0@BUPD.('"H>O9;@'0BU0D%#'KBVPD2#'=B>D!P8GP#ZSX&XE$)!B)\(ML
M)!C!X`6)1"1("VPD2(M$)!`!Z8E,)!B)3"1(B<$/K-$"BY0D0`$``,'@'HG-
MBXPD1`$```G%BT0D.('"H>O9;HEL)#B#T0")RXG1,=(!R!':,VPD((E$)!")
M5"04BU0D0(M$)!@QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#'1"04
M`````,'@!8E$)$`+;"1`BT0D(`'IP>8>#ZSZ`HE,)$")3"00B=6+5"04"?6+
MM"1(`0``B6PD(('&H>O9;@'PBW0D.#'NBVPD2#'UB>D!P8M$)!")RXG&P>`%
MB40D2(M$)!B+;"1(#ZS6&XM4)!R)P<=$)!P`````"?4!Z\'@'C'_#ZS1`HG>
MB5PD2(N4)%`!``")RPG#BT0D.(G=B5PD.(M<)""!PJ'KV6X!T(M4)!0QZXML
M)$`QW8GI`<&)\`^L^!N)1"08B?"+;"08P>`%B40D0`ML)$"+1"00`>F)3"1`
MB4PD&(G!#ZS1`HN4)%@!``#!X!Z)S8N,)%P!```)Q8M$)""!PJ'KV6Z);"0@
M@]$`B<N)T3'2`<@1VC-L)#B)1"00B50D%(M4)$B+1"08QT0D%``````QZHG1
MBU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)1"1("VPD2(M$)#@!Z<'F
M'@^L^@*)3"00B4PD2(G5BU0D%`GUB[0D8`$``(EL)#B!QJ'KV6X!\(MT)"`Q
M[HML)$`Q]8GI`<&+1"00B<N)QL'@!8E$)$"+1"08BVPD0`^LUAN+5"0<B<$)
M]0'KP>`>,?\/K-$"B=Z)7"1`BY0D:`$``(G+"<.+1"0@QT0D'`````")W8E<
M)""+7"0X@<*AZ]EN`="+5"04,>N+;"1(,=V)Z0'!B?`/K/@;B40D&(GPBVPD
M&,'@!8E$)$@+;"1(BT0D$`'IB4PD&(E,)$B)P0^LT0*+E"1P`0``P>`>B<V+
MC"1T`0``"<6+1"0X@<*AZ]ENB6PD.(/1`(G+B=$QT@'($=HS;"0@B40D$(E4
M)!2+5"1`BT0D&,=$)!0`````,>J)T8M4)!P#3"00#ZS0&XGRB40D$(M$)!B+
M;"00P>`%B40D0`ML)$`!Z<'F'@^L^@*)3"1`B4PD$(G5"?6+M"1X`0``BT0D
M((EL)""+5"04@<:AZ]EN`?"+="0X,>Z+;"1(,?6)Z0'!BT0D$(G+B<;!X`6)
M1"1(BT0D&(ML)$@/K-8;BU0D'(G!QT0D'``````)]0'KP>`>,?\/K-$"B=Z)
M7"1(BY0D@`$``(G+"<.+1"0XB=V)7"0XBUPD(('"H>O9;@'0BU0D%#'KBVPD
M0#'=B>D!P8GP#ZSX&XE$)!B)\(ML)!C!X`6)1"1`"VPD0(M$)!`!Z8E,)$")
M3"08B<$/K-$"BY0DB`$``,'@'HG-BXPDC`$```G%BT0D(('"H>O9;HEL)""#
MT0")RXG1,=(!R!':,VPD.(E$)!")5"04BU0D2(M$)!C'1"04`````#'JB=&+
M5"0<`TPD$`^LT!N)\HE$)!"+1"08BVPD$,'@!8E$)$@+;"1(BT0D.`'IP>8>
M#ZSZ`HE,)$B)3"00B=6+5"04"?6+M"20`0``B6PD.('&H>O9;@'PBW0D(#'N
MBVPD0#'UB>D!P8M$)!")RXG&P>`%B40D0(M$)!B+;"1`#ZS6&XM4)!R)P0GU
M`>O!X!XQ_P^LT0*)WHE<)$"+E"28`0``B<L)PXM$)"")W8E<)""+7"0X@<*A
MZ]EN`=`QZXML)$@QW8GI`<&)\`^L^!N)1"08B?"+;"08P>`%B40D2`ML)$B+
M1"00BU0D%,=$)!P``````>F)3"08B4PD2(G!#ZS1`HN4)*`!``#!X!Z)S8N,
M)*0!```)Q8M$)#B!PJ'KV6Z);"0X@]$`B<N)T3'2`<@1VC-L)"")1"00B50D
M%(M4)$"+1"08QT0D%``````QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML
M)!#!X`6)1"1`"VPD0(M$)"`!Z<'F'@^L^@*+?"1(B4PD$(G5B4PD6(M4)!0)
M]8NT)*@!``");"1`@<:AZ]EN`?"+="0X,>XQ]XGY`<&+1"00B<N)QL'@!0^L
MUAL)Q@'S,?^)7"1(BT0D&(G>BU0D'(G!P>`>#ZS1`HN4)+`!``")RXN,)+0!
M```)PXM$)#B!PJ'KV6Z)W8/1`(EL)"")RXG1,=(!R!':BUPD0(E$)!B)5"0<
MBU0D6(GPQT0D'``````QZS':B=$#3"08BU0D%`^L^!N)1"08B?"+;"08P>`%
MB40D.`ML)#B+1"00`>F)3"08B4PD6(G!#ZS1`HN4)+@!``#!X!Z)S0G%BT0D
M0('"W+P;CXEL)#B)T8M4)"`!P8G0(U0D.`GH(T0D2(E4)!"+5"0<B<4+;"00
MBT0D&`'I#ZS0&XGRB40D$(M$)!C!X`6)1"1`BVPD$`ML)$"+1"0@QT0D%```
M``#'1"0D``````'IP>8>#ZSZ`HE,)$B)3"00B=,)\XG?BYPDP`$``(G^B?J)
M?"1`BWPD',=$)!P`````@</<O!N/B=D!P8M$)#@)QB-T)%@APHM$)!")]8G&
M"=6+5"04`>G!X`6)1"0@BVPD((G+#ZS6&XN4),@!```)]8MT)!@!ZXE<)"")
M7"18B?'!YAX/K/D"B?"+?"1`B<Z+3"1("<:+1"0X@<+<O!N/B?.)]8ET)#@!
MT`G[(?TAV8GKB<*)S8M$)""+?"04"=T!ZHG1BU0D)(G&P>`%B<L/K-8;BY0D
MT`$```G&BT0D0`'SBW0D$(E<)$B)7"08BUPD.,=$)!0`````B?'!YAX/K/D"
MBWPD),=$)"0`````B<V+3"18"?6!PMR\&X^)W@'0">XAZR'QB<*+1"08"=F)
M;"1``<J)T8M4)!R)QL'@!8G+B40D$(ML)!`/K-8;BY0DV`$``(M$)#@)]8MT
M)"`!ZXML)$")7"18B5PD$(GQP>8>#ZSY`HG/BTPD2`GW@<+<O!N/B?X!T(G[
M">XAZXG"(?&+1"00B7PD.(G-BWPD'`G=`>J)QL'@!8G1BU0D%(E$)""+;"0@
MB<L/K-8;BY0DX`$```GUBW0D&`'KB5PD((E<)$B)\<'F'@^L^0*)\(M\)#B)
MSHM,)%@)QHM$)$"!PMR\&X^)\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W0'J
MB=&+5"0DB<;!X`6)RP^LUAL)Q@'SB5PD6(MT)!"+?"04B5PD&(N4).@!``"+
M7"1`B?&+1"0XP>8>#ZSY`L=$)!P`````BWPD)(G-BTPD2,=$)!0`````"?6!
MPMR\&X^)W@'0">XAZR'QB<*+1"08"=F);"0XQT0D)``````!RHG1BU0D'(G&
MP>`%B<N)1"00BVPD$`^LUAN+E"3P`0``BT0D0`GUBW0D(`'KBVPD.(E<)!")
M7"1(B?'!YAX/K/D"B<^+3"18"?>!PMR\&X^)_@'0B?L)[B'KB<(A\8M$)!")
M?"1`B<V+?"0<"=T!ZHG&P>`%B=&+5"04B40D((ML)"")RP^LUAN+E"3X`0``
M"?6+="08`>N)7"18B5PD((GQP>8>#ZSY`HGPB<X)QHM$)#B+?"1`BTPD2('"
MW+P;CXGSB70D.,=$)!P``````=`)^R'9B?.)PB'[B<V+1"0@"=V+?"04QT0D
M%``````!ZHG1BU0D)(G&P>`%B<L/K-8;BY0D``(```G&BT0D0`'SBW0D$(E<
M)$B)7"08BUPD.(GQP>8>#ZSY`HM\)"2)S8M,)%@)]8'"W+P;CXG>`=`)[B'K
M(?&)PHM$)!@)V8EL)$`!RHG1BU0D'(G&P>`%B<N)1"00BVPD$`^LUAN+E"0(
M`@``BT0D.`GUBW0D(`'KBVPD0(E<)!")7"18B?'!YAX/K/D"B<^+3"1("?>!
MPMR\&X^)_@'0B?L)[B'KB<(A\8M$)!")?"0XB<T)W0'JB<;!X`6)T8M4)!2)
M1"0@BVPD((M\)!R)R\=$)"0`````QT0D'``````/K-8;BY0D$`(```GUBW0D
M&`'KB5PD2(E<)"")\<'F'@^L^0*)\(M\)#B)SHM,)%@)QHM$)$"!PMR\&X^)
M\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W8M\)!3'1"04``````'JB=&+5"0D
MB<;!X`6)RP^LUAN+E"08`@``"<:+1"0X`?.+="00B5PD&(E<)%B+7"1`B?'!
MYAX/K/D"BWPD)(G-BTPD2`GU@<+<O!N/B=X!T`GN(>LA\8G"BT0D&`G9B6PD
M.`'*B=&+5"0<B<;!X`6)RXE$)!"+;"00#ZS6&XN4)"`"```)]8MT)"`!ZXE<
M)$B)7"00B?&+1"1`P>8>#ZSY`HML)#C'1"0D`````(G/BTPD6`GW@<+<O!N/
MB?X!T(G[">XAZXG"(?&+1"00B7PD0(G-BWPD',=$)!P`````"=T!ZHG&P>`%
MB=&+5"04B40D((ML)"")RP^LUAN+E"0H`@``"?6+="08`>N)7"18B5PD((GQ
MP>8>#ZSY`HGPBWPD0(G.BTPD2`G&BT0D.('"W+P;CXGSB70D.`'0"?LAV8GS
MB<(A^XG-BT0D(`G=BWPD%`'JB=&+5"0DB<;!X`6)RP^LUAN+E"0P`@``"<:+
M1"1``?.+="00B5PD&(E<)$B+7"0XB?'!YAX/K/D"B<V+3"18"?6!PMR\&X^)
MW@'0">XAZR'QB<*+1"08"=F);"1``<J)T8M4)!R)QL'@!8G+B40D$(ML)!`/
MK-8;BWPD)(N4)#@"```)]8MT)""+1"0X`>N+;"1`QT0D%`````")7"18B5PD
M$(GQP>8>QT0D)``````/K/D"B<^+3"1("?>!PMR\&X^)_@'0B?L)[B'KB<(A
M\8M$)!")?"0XB<V+?"0<QT0D'``````)W0'JB<;!X`6)T8M4)!2)1"0@BVPD
M((G+#ZS6&XN4)$`"```)]8MT)!@!ZXE<)"")7"1(B?'!YAX/K/D"B?"+?"0X
MB<Z+3"18"<:+1"1`@<+<O!N/B?.)="1``=`)^R'9B?.)PB'[B<V+1"0@"=V+
M?"04`>J)T8M4)"2)QL'@!8G+#ZS6&XN4)$@"```)Q@'SBW0D$(E<)%B)7"08
MBT0D.(M<)$")\<'F'L=$)!0`````#ZSY`HM\)"3'1"0D`````(G-BTPD2`GU
M@<+<O!N/B=X!T`GN(>LA\8G"BT0D&`G9B6PD.`'*B=&+5"0<B<;!X`6)RXE$
M)!"+;"00#ZS6&XN4)%`"``"+1"1`"?6+="0@`>N+;"0XB5PD2(E<)!")\<'F
M'@^L^0*)SXM,)%@)]X'"W+P;CXG^`=")^PGN(>N)PB'QBT0D$(E\)$")S8M\
M)!P)W0'JB<;!X`6)T8M4)!2)1"0@BVPD((G+#ZS6&XN4)%@"```)]8MT)!@!
MZXML)$B)7"0@B5PD6(GQP>8>#ZSY`HGPB<X)QHM$)#B!PM;!8LJ)="08`=`S
M="1`,?6)Z0'!BT0D((M4)"2)R\=$)!P`````B<;!X`4/K-8;BU0D%,=$)!0`
M````"<:+1"00`?,Q_XE<)$B)WHM<)!B)P<'@'@^LT0*+E"1@`@``B<T)Q8M$
M)$"!PM;!8LJ);"0X`=`QZXML)%B+5"0D,=V)Z0'!B?`/K/@;B40D$(GPBVPD
M$,'@!8E$)$`+;"1`BT0D(`'IB4PD$(E,)$")P0^LT0+!X!Z+E"1H`@``B<T)
MQ8M$)!B!PM;!8LJ);"0@`=`S;"0XBU0D%#-L)$B)Z0'!BT0D$`^LT!N)\HE$
M)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAX/K/H"B?")3"1(B4PD&(G6BY0D
M<`(``(ML)$`)QHM$)#B)="0X@<+6P6+*`=`S="0@BU0D'#'UB>D!P8M$)!B)
MRXG&P>`%#ZS6&XM4)!3'1"04``````G&BT0D$`'S,?^)WHE<)$"+7"0XB<'!
MX!X/K-$"BY0D>`(``(G-"<6+1"0@@<+6P6+*B6PD(`'0,>N+;"1(BU0D'#'=
MB>D!P8GP#ZSX&XE$)!")\(ML)!#!X`6)1"1("VPD2(M$)!@!Z8E,)!")3"1(
MB<$/K-$"P>`>BY0D@`(``(G-"<6+1"0X@<+6P6+*B6PD.`'0,VPD((M4)!0S
M;"1`B>D!P8M$)!`/K-`;B?*)1"08BT0D$,'@!8E$)$"+;"08"VPD0,=$)!P`
M`````>G!YAZ+;"1(#ZSZ`HGPB4PD0(E,)!B)UHN4)(@"```)QHM$)"")="0@
M@<+6P6+*`=`S="0XBU0D'#'UB>D!P8M$)!B)RXG&P>`%#ZS6&XM4)!3'1"04
M``````G&BT0D$`'S,?^)WHE<)$B+7"0@B<'!X!X/K-$"BY0DD`(``(G-"<6+
M1"0X@<+6P6+*B6PD.`'0,>N+;"1`BU0D'#'=B>D!P8GP#ZSX&XE$)!")\(ML
M)!#!X`6)1"1`"VPD0(M$)!@!Z8E,)$")3"00B<$/K-$"P>`>BY0DF`(``(G-
M"<6+1"0@@<+6P6+*B6PD(`'0,VPD.#-L)$B+5"04QT0D'`````")Z0'!BT0D
M$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ+;"1`#ZSZ`HGP
MB4PD2(E,)!B)UHN4)*`"```)QHM$)#B)="0X@<+6P6+*`=`S="0@BU0D'#'U
MB>D!P8M$)!B)RXG&P>`%#ZS6&XM4)!3'1"04``````G&BT0D$`'S,?^)WHE<
M)$"+7"0XB<'!X!X/K-$"BY0DJ`(``(G-"<6+1"0@@<+6P6+*B6PD(`'0,>N+
M;"1(,=V)Z0'!B?`/K/@;B40D$(GPBVPD$,'@!8E$)$@+;"1(`>F)3"1(B4PD
M$(M$)!B+5"0<QT0D'`````")P<'@'@^LT0*+E"2P`@``B<T)Q8M$)#B!PM;!
M8LJ);"0X`=`S;"0@BU0D%#-L)$")Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD
M&,'@!8E$)$`+;"1``>G!YAZ+;"1(#ZSZ`HGPB4PD0(E,)!B)UHN4)+@"```)
MQHM$)"")="0@@<+6P6+*`=`S="0XBU0D'#'UB>D!P8M$)!B)RXG&P>`%#ZS6
M&XM4)!0)QHM$)!`!\S'_B=Z)7"1(BUPD((G!P>`>#ZS1`HN4),`"``")S0G%
MBT0D.('"UL%BRHEL)#@!T#'KBVPD0#'=B>D!P8GP#ZSX&XE$)!")\,'@!8E$
M)$"+;"00"VPD0(M$)!B+5"0<QT0D%`````#'1"0<``````'IB4PD$(E,)$")
MP0^LT0+!X!Z+E"3(`@``B<T)Q8M$)""!PM;!8LJ);"0@`=`S;"0XBU0D%#-L
M)$B)Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ+
M;"0@#ZSZ`HGPB4PD&(E,)$B)UHN4)-`"```)QHM$)#B)="0X@<+6P6+*`=`Q
M]8M4)!R)[HML)$`Q]8GI`<&+1"08B<N)QL'@!0^LUAN+5"04"<:+1"00`?,Q
M_XE<)%B)WHG!P>`>#ZS1`HN4)-@"``")S8N,)-P"``#'1"0D``````G%BT0D
M(('"UL%BRHEL)$"#T0")RXG1,=(!R!':BUPD.#'KBVPD2#'=,=N)Z0'!B?`1
MTS'2#ZSX&XE$)!")\(ML)!#!X`6)1"0@"VPD((M$)!@!Z1'3B<J)P8E4)"")
M5"1(P>`>BU0D'(E<)$P/K-$"BY0DX`(``(G-BXPDY`(```G%BT0D.('"UL%B
MRHEL)!B#T0")RXG1,=(!R!':,VPD0#';,VPD6(GI`<&+1"0@$=.+5"0D#ZS0
M&XM4)"2)1"00BT0D((ML)!`/I,(%P>`%B40D.`ML)#B)5"0\,=(!Z1'3B<J)
M5"18B50D$(GR#ZSZ`L'F'HE<)%S'1"04`````(GPB=:+E"3H`@``"<:+1"1`
MBVPD2(ET)#B+7"04@<+6P6+*`=`S="08BU0D%#'UB>D!P8M$)!")QL'@!0^L
MUAN+5"0D"<:)\`'(,?^)QHM$)"")P<'@'@^LT0*+5"00B<V+3"04"<6+1"08
MB6PD2`^LR@+!Z0*)3"0DBTPD$(E4)""+E"3P`@``#Z3+'L'A'H'"UL%BRHE<
M)!2+7"0X`=")3"00B?HQZXML)%@QW8GI`<&)\,'J&P^L^!N)5"0<B?J)1"08
MB?"+;"08P>`%B40D0`ML)$`/I/(%B50D1(GH`<B)P0-,)"B+1"1HB</'0`0`
M````B0B+!"2+;"0@QT,,`````,=#%`````#'0QP``````?`+;"00QT,D````
M`(E#"(GH`T0D"(E#$(M$)$@#1"0PB4,8BT0D.`-$)%")0R"+A"3\`@``93,%
M%````'4+@<0,`P``6UY?7</H/]3__^L-D)"0D)"0D)"0D)"0D(7`#X2;````
M55=64X/L'(L-0$$%"(7)B4PD"'15#[8(@/D]=%N$R717B<.#PP$/M@N`^3UT
M!(3)=?$IPXM,)`B+*87M="R)5"0,B<:)SV:0@^P$4U95Z,76__^#Q!"%P'4'
M@'P=`#UT'X/'!(LOA>UUWH/$'#'`6UY?7<.-="8`,=OKN(UT)@")^BM4)`B+
M1"0,P?H"B1"#Q!R-1!T!6UY?7<,QP,.-=@"-O"<`````4XG#@^P89:$4````
MB40D##'`C50D"(G8Z#/___^%P'0ZC;0F`````*%`004(BU0D"(T4D(M*!(7)
MB0ITU8UV`(/"!(M*!(7)B0IU](U4)`B)V.CY_O__A<!US8M$)`QE,P44````
M=06#Q!A;P^@.T___C;0F`````(V\)P````!55XG'5E.)TX/L.&6A%````(E$
M)"@QP#'`@#H]#Y3``<-3Z#G4__^#Q!")Q8GXC50D&.B9_O__A<")Q@^$]P``
M`(/L#%#H%M3__X/$$#G%#X;+````BT0D&(T,A0`````/M@<\/0^$@P$``(3`
M#X1[`0``B?CK#8GVC;PG`````(32=`N#P`$/MA"`^CUU\2GXC40H`H/L#(LU
M0$$%"%`!SNA*T___@\00A<")!@^$3@$``*%`004(BU0D&(U/`8L4D`^V!X3`
MB`)U%>L7C78`@\$!#[9!_X/"`83`B`)T!#P]=>S&`CTQP(VT)@`````/M@P#
MB$P"`8/``83)=?$QP(M\)!QE,ST4````#X7Y````@\0L6UY?7<.-M@````"#
MPP$/MD/_@\8!A,"(1O]U[^O,D(UT)@"+%4!!!0B+`H7`#X2M````,?:-M@``
M``"#Q@&+!+*%P'7VC02U"````(L-@%$%"(7)=#6#[`A04NAKTO__@\00A<"C
M0$$%"`^$?````(T,M0````#'1+`$`````(ET)!CIP_[__XUV`(E4)`B#[`S'
M!8!1!0@!````4.@YTO__@\00A<!T0XT,M0````"#[`11BU0D$(E,)!12B40D
M%%#HI-#__XM$)!B#Q!"+3"0,HT!!!0CKGC'`Z9S^__^X"````#'VZ6#___^X
M_____^GV_O__Z/#0__]55U93B<:![(P```!EH10```")1"1\,<"%]G0%@#X`
M=1^+1"1\93,%%`````^%'P$``('$C````%M>7UW#C78`@^P,5NCWT___@\00
MA<")QW3/C;8`````@^P,5^A/T___@\00A<")PP^$N@```(![$RX/A(@```"#
M[`R-:Q-6Z,S1__^)+"2)1"0<Z,#1__^+3"0<C40!`HD$).A`T?__B<-86E56
M:/#?!`AJ_VH!4^B;T___@\0<C40D(%!3:@/H*]/__X/$$(/X_W00BT0D+"4`
M\```/0!```!T:X/L#%/H*M#__X/$$(/L#%/HCL___X/$$.E>____C;8`````
M#[9#%(3`#X1,____/"X/A63___^`>Q4`#X0Z____Z57___^0C70F`(/L#%?H
M_]+__XDT).B'S___@\00Z>#^__^-M"8`````B=CHL?[__^N8Z)K/__^-=@"-
MO"<`````5E.#[!#_-4A!!0CHD-+__XN`@````%N+<`3_-4A!!0CH>]+__P^V
M6&58_S5(004(@^-_Z&C2__^+0`0/MT`0P>`'"<-FB5X"6/\U2$$%".A,TO__
MBX"`````BU@$6/\U2$$%".@WTO__@\0,:@!HQ>$$"%#HI]#__XE#'%C_-4A!
M!0CH&-+__XN`@````(M8!%C_-4A!!0CH`]+__XN`T`,``(E#(%C_-4A!!0CH
M[M'__XN`@````%J+6`3_-4A!!0CHV='__XN(\````(/$$#'2A<ET&H/L#/\U
M2$$%".B\T?__BX#P````@\00BU!P@^P,B5,D_S5(004(Z)_1__^+@(````"+
M0`3'0"@`````6/\U2$$%".B#T?__BX"`````BT`$QT`8`````%K_-4A!!0CH
M9]'__XN`@````%F+6`3_-4A!!0CH4M'__XN`_`$``(E#+(/$%%M>PXUV`%.)
MPX/L%/\U2$$%".@OT?__C9#\````@\0,4E-J`^@MT?__@\00A<!T#H/$"#'`
M6\.-M"8`````@^P,_S5(004(Z/K0__^+@`P!``"#Q!`E`/```#T`0```=".#
M[`S_-4A!!0CHU]#__XN`#`$``(/$$"4`\```/0"@``!UK(/L"&H"4^@'T/__
M@\00A<`/E,"#Q`@/ML!;PXVT)@````!55XG'5E.)U8'L(!```&6A%````(F$
M)!`0```QP&C_#P``C70D%%9H]M\$".BOS?__@\00A<!^8(U8_X!\'`P`=$Z)
MPX/L!%-J+U;H0,___X/$$(7`=$&#[`S_-4A!!0CH.]#__U-65U#HPL___X/$
M((N$)`P0``!E,P44````=36!Q!P0``!;7E]=PXUT)@"%VW6PC70F`(/L#/\U
M2$$%".CZS___@\0,55=0Z#_-__^#Q!#KN^C5S/__D(UT)@"#[!C_-4A!!0CH
MTL___VCVX00(:#"3!`AH!>`$"%#H7<[__X/$+,.)]HV\)P````"#[!C_-4A!
M!0CHHL___XD$).BZ____6/\U2$$%".B.S___6EEJ`&C%X00(:,7A!`AHH-H$
M"&@AX`0(4.BPSO__@\0LPXVV`````(V_`````%=64X'L$"```&6A%````(F$
M)`P@```QP.CSS/__@^P(:`'@!`A0:#;@!`AH`1```&H!C5PD)E/H=,___X/$
M((7`>&6#[`1H`!```(V\)!,0``!74^A'S/__@\00A<")QGA&C4`!@^P,4.C2
MS/__@\00A<")PW0Q@^P$5E=0Z&[+___&!#,`@\00B=B+E"0,(```93,5%```
M`'41@<00(```6UY?PXUV`#'`Z]_HG\O__^L-D)"0D)"0D)"0D)"0D.D[____
MC70F`(V\)P````!55U93@>PL$```BYPD0!```(U4)!B+O"1$$```9:$4````
MB80D'!```#'`N$3@!`CH&_?__X/L"(G&:B]3Z'[,__^#Q!"%P'0MB=JX3>`$
M".@K^/__B=B+C"0<$```93,-%`````^%3`$``('$+!```%M>7UW#@^P,4^AA
MS/__6EF)1"04:%K@!`A7Z&#-__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT)@"%
M[72=@'T``+A"X`0(#T3HA?9T%8/L"%56Z`K*__^#Q!"%P`^$G@```(/L#%7H
M!LS__X/$$(!\!?\O=1.-="8`@^@!@'P%_R_&1`4``'3QBTPD#(T4`8'Z_P\`
M``^//____X/L!%-H7.`$"%5H@.$$"&@`$```:@%7Z+K-__^#Q!3_-4A!!0CH
M7,W__X/$#`7\````4%=J`^@[S?__@\00A<!U(X/L#/\U2$$%".@VS?__BX`,
M`0``@\00)0#P```]`(```'09@^P(:%K@!`AJ`.ARS/__@\00B<7I(/___X/L
M"&H!5^A-S/__@\00A<!UU8GZN$W@!`CHVO;__X/L#%?HH<O__X/$$.F@_O__
MZ,3)__^-="8`BT0D!`^V"(3)=!6-4`%FD(#Y+P^V"@]$PH/"`83)=?#SPXVT
M)@````"-O"<`````4X/L&(M<)""%VW1<#[83A-)T58A4)`^#[`Q3Z-#*__^-
M1`/_@\00#[94)`\YPW(/ZRJ-M@````"#Z`$YV'0=@#@O=/3K#XUV`(V\)P``
M``"`."]T0(/H`3G#<O0YPW4U@/HO=7*-=@"#[`QJ`N@.RO__@\00A<!T5[HN
M````9HD0@\086\.-=@"-O"<`````@#@O=0>#Z`$YPW+T*=B-4`*!^@`0``!W
M)X/``6@`$```4%-H@$$%".@#R___@\00N(!!!0B#Q!A;PXVV`````(/$&#'`
M6\/'1"0@7.`$"(/$&%OI>,K__Y"-M"8`````5U:#[#1EH10```")1"0L,<"A
MU.$$"(E$)`JAV.$$"(E$)`ZAW.$$"(E$)!*AX.$$"(E$)!:AY.$$"(E$)!JA
MZ.$$"(E$)!ZA[.$$"(E$)"*A\.$$"(E$)"8/MP7TX00(9HE$)"JX7N`$".BQ
M]/__N&?@!`CHI_3__[AOX`0(Z)WT__^X>.`$".B3]/__N'_@!`CHB?3__[B/
MX`0(Z'_T__^X1.`$".AU]/__N)O@!`CH:_3__[BEX`0(Z&'T__^XK^`$".A7
M]/__N$W@!`CH3?3__[BYX`0(Z$/T__^XPN`$".@Y]/__C50D!+C-X`0(Z'OS
M__^%P'0,B<*XI>`$".B;]/__C50D!+C>X`0(Z%WS__^%P'0,B<*X\.`$".A]
M]/__C50D!+C[X`0(Z#_S__^%P'0SB<*X1.`$".A?]/__NB?A!`BX?^`$".A0
M]/__BT0D+&4S!10```!U58/$-%Y?PY"-="8`C50D!+@+X00(Z/KR__^%P'06
MB<*XF^`$".@:]/__Z[F0C;0F`````(UT)!N_'.$$"+D*````\Z9UGXU4)"6X
MF^`$".CP\___ZX_HZ<;__XGVC;PG`````(/L'&6A%````(E$)`PQP*$@004(
M@_C_=!>+3"0,93,-%````'4^@\0<PXVV`````(U4)`BXF^`$".AR\O__A<!T
M'@^V$(32#Y7`@/HP#Y7"#[;2(="C($$%".N]C70F`#'`Z_'H=\;__XVT)@``
M``"#[`SH>,;__X/L#%#HS\7__X/$$(7`=`B+`(/$#,-FD#'`Z_:-M@````"-
MOP````!55[\SX00(5E.[*>$$"(/L3(ML)&#'1"0@,^$$"(UT)"AEH10```")
M1"0\,<#'1"0D*>$$",=$)"@VX00(QT0D+"SA!`C'1"0P,>$$",=$)#1#X00(
MQT0D.`````#K(Y"#[`A54(E$)!CH$L7__X/$$(7`=$N%VW0JBP:)WX/&!(G#
MC50D'(GXZ(/Q__^%P'0%@#@`=<J)ZHGXZ*'R__^%VW76BT0D/&4S!10```!U
M<8/$3%M>7UW#D(VT)@````"#[`Q5Z-?&__^+3"08B40D'(D,)(E,)!CHP\;_
M_XM4)!R-1`("B00DZ$/&__^#Q`R+3"0,46A:X`0(56B`X00(:O]J`5")1"0H
MZ)+(__^#Q""+5"0(B?CH)/+__^E4____Z!K%__^-=@"-O"<`````55=64X'L
M'($``(N$)#"!``"-5"0<QT0D(%KA!`C'1"0D0N`$",=$)"@`````QT0D./#@
M!`C'1"0\Z>`$"(D$),=$)$!?X00(9:$4````B80D#($``#'`N$3@!`C'1"1$
M!N$$",=$)$AGX00(QT0D3`````#'1"0L3N$$",=$)#!KX00(QT0D-`````#H
M3_#__X7`=`F`.``/A0($``#H_?W__X7`B<,/A!0$``"#[`Q3Z+K%__^-1``!
M@\00@^P,4.@ZQ?__@\00@#L`B<:)QW0JC;8`````#[8#@^P,@\,!4&ATX00(
M:O]J`5>#QP+H?,?__X/$((`[`'7<C7PD/+CPX`0(ZQ.)]HV\)P````"#QP2+
M1_R%P'0VC50D'.B][___A<")PW3G@#@`=.+HK?7__X7`=-F#[`Q3Z*#%__^#
MQ!"%P(G%=5F-M"8`````BUPD((7;=$B`.P"_`0```'46ZSR-="8`BUR\((7;
M=#"#QP&`.P!T*(G8Z&'U__^%P'3E@^P,4^A4Q?__@\00A<!TU8G%ZPN)]HV\
M)P`````Q[8/L#(GS5>C#Q/__@\00BPN#PP2-D?_^_O[WT2'*@>*`@("`=.F)
MU\'O$/?"@(````]$UXU[`@]$WP#2@]L#@^P,*?.-G`,$!```4^@.Q/__B40D
M&%:)QFAYX00(:%S@!`A5:'[A!`AJ_VH!4.A=QO__@\0H:,`!``!6Z*_$__^#
MQ!"#^/]T;X/L#/\U2$$%".CIQ?__@\0,!?P```!0_W0D$&H#Z.7%__^#Q!"%
MP'1N@^P,_W0D%(M$)!#_,&@\X@0(:@'_-41!!0CH;\7__X/$(#'`BXPD#($`
M`&4S#10````/A:@)``"!Q!R!``!;7E]=PXUV`.ACQ/__BP"#^!%TA8/L"%#_
M="04BT0D$/\P:`#B!`CKJXVT)@````"#[`S_-4A!!0CH4L7__XN`#`$``(/$
M$"4`\```/0!````/A6O___^#[`S_-4A!!0CH*\7__XNP%`$``.@@PO__@\00
M.<8/A4?___^#[`S_-4A!!0CH!\7__XN`#`$``(/$$"7_`0``/<`!```/A2#_
M__^#[`Q3Z,7"__^-5"0LB40D'+@LX00(Z)/M__^#Q!"%P`^$N`@``(/L#%#H
M?\/__UI94(M$)`S_,.@A]O__@\00A<")PP^$E`@``(/L#%/HZ\+__X/$$(/X
M`WXKC70#_+^'X00(N04```#SIG49@_@$#X36!@``@'P#^R\/A,L&``"0C70F
M`.AS^O__A<!U&H/L"&H`4^C$PO__B40D$(/$$(7`#X4U`0``NB?A!`BXF^`$
M"#';Z"3N___HW\'__VC%X00(4&A<X`0(BWPD%%=HH.$$"&K_:@&+="0H5NA<
MQ/__@\0@ZSN-M"8`````Z-O"__^#.!%U0.BAP?__@\,!@^P,:,7A!`A34&A<
MX`0(5VBNX00(:O]J`5;H'\3__X/$,(/L"&C``0``5NANPO__@\00@_C_=+:#
M[`S_="04Z"K`__^+="0<N$3@!`B)\NB*[?__B30DZ$+Z__^#Q!")\.G>_?__
MD(VT)@````"#[`Q0B40D&.@C^O__BT0D&(D$).@GPO__@\00Z;7]__^X3N$$
M"+X!````ZPZ-=@"+1+0L@\8!A<!T*8U4)!SH_.O__X7`=.B`.`!TXX/L#%#H
MZL'__X/$$(7`=-.)P^FI^___L`V[4^$$".FM^___:@)J_VKNBW0D#%;HH,#_
M_X/$#&H&C80D%`$``%!6Z#V___^#Q!"`O"0,`0```'4.@+PD#0$``$,/A"X&
M``!J`&H`:@#_="0,Z&/`___'1"1@`2-%9\=$)&0`````QT0D:(FKS>_'1"1L
M`````,=$)'#^W+J8QT0D=`````#'1"1X=E0R$,=$)'P`````QX0D@````/#A
MTL/'A"2$`````````,>$)(@`````````QX0DC`````````#'A"20````````
M`,>$))0`````````QX0DV`````````"#Q!"-=@"#[`1H`(```(V$)!0!``!0
M_W0D#.AGOO__@\00A<")Q0^.ZP$``(M,)'B+7"1\B>B)[\'@`XGNP?\?`<B#
M^P`/A[,!```YP0^'JP$``(N,)(````"+G"2$````#ZS^'8E$)'B+A"3(````
MP>\=`?''1"1\`````!'[B8PD@````(7`B9PDA`````^$60$``+]`````*<>-
MA`2(````.?T/3OV#[`17C8PD%`$``%%0Z`R^__^+A"38`````?B)A"38````
M@\00@_A`#X4P____C80D#`$``"G]`<>-1"10Z,S$__^-="8`@_T_#X[3````
MB>Z)^XUV`(L#@^Y`@\-`B80DB````(M#Q(F$)(P```"+0\B)A"20````BT/,
MB80DE````(M#T(F$))@```"+0]2)A"2<````BT/8B80DH````(M#W(F$)*0`
M``"+0^")A"2H````BT/DB80DK````(M#Z(F$)+````"+0^R)A"2T````BT/P
MB80DN````(M#](F$)+P```"+0_B)A"3`````BT/\B80DQ````(U$)%#H"L3_
M_X/^/P^/2?___X/M0(GHP>@&C5`!P>`&*<7!X@8!UVI$55>-A"24````4.A;
MOO__B:PDV````(/$$.D<_O__C70F`(V\)`P!``#I]/[__XUT)@"+C"2`````
MBYPDA````(/!`8/3`.E*_O__@^P,_W0D#.@SP/__BX0DD````(N<)(@```"+
MM"2,````BY0DE````(E$)!")V`^L\`.)5"04B<*#XC^-0@'&A!28````@(/$
M$(/X.`^/9@(``+@W````C8P4@0```"G0@_@$C5$(#X.5`@``A<!T#*@"QD$(
M``^%G0,``(L\)(ML)`2(G"3'````B?@/K.@8B(0DP````(GX#ZSH$(B$),$`
M``")^`^LZ`B-K"3C````B(0DP@```(GXC;PDT````(B$),,```")V`^L\!B(
MA"3$````B=@/K/`0B(0DQ0```(G8#ZSP"(B$),8```"-1"10Z*?"__^+1"10
MBU0D5(M<)%R)P8B$)-(````/K-$8B<Z(C"3/````B<$/K-$0B(PDT````(G!
M#ZS1"(B,)-$```"+3"18B<B(C"36````#ZS8&(B$)-,```")R`^LV!"(A"34
M````B<B+3"1@#ZS8"(M<)&2(A"35````B<B(C"3:````#ZS8&(B$)-<```")
MR`^LV!"(A"38````B<B+3"1H#ZS8"(M<)&R(A"39````B<B(C"3>````#ZS8
M&(B$)-L```")R`^LV!"(A"3<````B<B+3"1P#ZS8"(M<)'2(A"3=````B<B(
MC"3B````#ZS8&(B$)-\```")R`^LV!"(A"3@````B<@/K-@(C9PD"P$``(B$
M).$```")\.D/````B?:-O"<`````#[8'@\<!@^P,#[;`4&ATX00(:O]J`56#
MQ0+H,;[__X/$(#G===K&A"0+`0```&C%X00(C80DYP```%!H7.`$"/]T)!1H
MD>$$"&K_:@'_="0HZ/J]__^#Q"#I[/G__XL$)(MH!(7M#X0L^?__@^P,5>C;
MN___@\00@_@##X87^?__C70%_+^,X00(N04```#SI@]$W>G_^/__N#\````I
MT(G!C804@0```(/Y!(U0"'-NA<ET#?;!`L9`"``/A40!``"-1"10Z+7`__^-
ME"2(````N0X````QP(G7\ZOI>_W__\=!"`````"#P0S'1!#\`````(/A_"G*
M`<*#XOR#^@0/@E;]__^#XOPQP,<$`0````"#P`0YT'+RZ3[]__^->`S'0`@`
M````B=#'1!'\`````(/G_"GX`<B#X/R#^`1R@(/@_(G!,<#'!`<`````@\`$
M.<AR\NEF____@+PD#@$``$$/A<3Y__^`O"0/`0``0P^%MOG__X"\)!`!``!(
M#X6H^?__@+PD$0$``$4/A9KY__]J`FK_:L:+="0,5NC\N?__@\0,:BF-A"04
M`0``4%;HF;C__VC%X00(C80D(`$``%!H7.`$"/]T)"1HD>$$"&K_:@'_="0X
MZ'&\__^#Q##I8_C__XGVC;PG`````(L$)(L8Z6+W__\Q_V:)?!#^Z5?\__\Q
M[6:);!'^Z;#^___HV;C__XGVC;PG`````%575E.#["AEH10```")1"08,<#_
M-4A!!0CHPKO__XU4)!C&0&$!N'_@!`CH<.3__X/$$(7`=`F`.#$/A%`"``#H
MZ^___X/L#/\U2$$%".B-N___:@MJ`6B_X00(4.ANN?__@\0@A<`/A+,```"#
M/8A1!0@!BT`,BW@8#XZ@````,?:[`0```.LQC;0F`````(M%#(/L"%"AA%$%
M"/\TF.A\M___@\00A<!U9:&(404(@\,!@\8!.=A^6X/L#/\U2$$%".@8N___
M:@!65U#H?KK__X/$((7`=#>+*(M%""4`!"``/0`$``!TIH/L#/\U2$$%".CH
MNO__:@)J`%50Z#VX__^#Q"#KBY"-M"8`````H8A1!0B-4/\Y\@^$,`$``(/L
M#/\U2$$%".BRNO__:@-J`6C$X00(4.B3N/__@\0@A<")PW0TBT`,@^P,BS#_
M-4A!!0CHA[K__X/$#&C&X00(5E#HR+?__XM##(/$$(L8]D,*0`^%$`(``(/L
M#/\U2$$%".A8NO__:@-J`6C+X`0(4.@YN/__@\0@A<")QG0YC50D"+A-X`0(
MZ/+B__^%P(G##X1H`0``BT8,@^P,BSC_-4A!!0CH%;K__X/$#%-74.A:M___
M@\00@^P,_S5(004(Z/FY__^-5"08QD!A`+A$X`0(Z*?B__^#Q!"%P(G#HXQ1
M!0@/A)4```"#[`AHP`$``%#H=[C__XU0`8/$$(/Z`78)@_@1#X6.`0``BT0D
M#&4S!10````/A7@!``"#Q!Q;7E]=PXUV`(V\)P````"#^`$/CL?^__^[`0``
M`&:0@^P,_S5(004(@\,!Z&^Y__]>75=0Z`:V__^#Q!`Y'8A1!0A_V^F6_O__
MC;8`````@'@!``^$J_W__^FA_?__D(/L#/\UA%$%".@2\?__@\00A<"CC%$%
M"`^$ZP```(M&#(L]A%$%"(L8BT,()0`$(``]``0```^%C0```(M##(/L"%=0
MZ">V__^)QXM&#(/$$(L8BU,(@>(`!"``@?H`!```=4>+0PQ74*&$404(_S!H
MM.($".A6M___C;8`````H811!0B#[`R+.(M&#(L8_S5(004(Z*:X__^)^HG8
MZ/WG__^#Q!#ICO[__X/L#/\U2$$%".B'N/__:@)J`%-0Z-RU__^#Q"#KGH/L
M#/\U2$$%".AIN/__:@)J`%-0Z+ZU__^#Q"#I5?___X/L#/\U2$$%".A(N/__
M6EE34.A/M___@\00Z=']__^#[`QHD.($".BZMO__Z!6U__]0H811!0A3_S!H
MW.($".BBMO__9I!64X/L$(MT)!Q6Z&'K__\/M@B#Q!")PX3)=!6-4`%FD(#Y
M+P^V"@]$VH/"`83)=?#HZ^W__X7`=!Z%]G0:@#X`=!6#[`AH>>$$"%/H\+/_
M_X/$$#G8=`:#Q`1;7L.#Q`2)\%M>Z:?C__^-M"8`````@^P8_S5(004(Z)*W
M__]:66K_4.@(M?__6/\U2$$%".A\M___@\0,:@!HX,,$"%#H/+?__X/$',-F
MD&:09I!FD%/H"KK__X'#VF```(/L&(N#'`$``(E$)`R+1"0HB40D"(M$)"2)
M1"0$BT0D((D$).B[M/__@\086\-FD&:09I!55S'_5E/HQ;G__X'#E6```(/L
M'(ML)#"-L_S^___H\;+__XV#^/[__RG&P?X"A?9T)XVV`````(M$)#B)+"2)
M1"0(BT0D-(E$)`3_E+OX_O__@\<!.?=UWX/$'%M>7UW#ZPV0D)"0D)"0D)"0
MD)"0\\,``%.#[`CH4[G__X'#(V```(/$"%O#`P````$``@`E<R\E<P`O<')O
M8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-4`!005)?4%)/
M1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$
M7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-
M4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A
M<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U
M)7,`05)'5@`8`'!E<FP`+64`+2T`````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```'!E<FQX<VDN8P`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!]
M(&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]
M("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2![
M"F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIS965K(%]&
M2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F
M(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L
M("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N
M86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN
M;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO
M9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X
M="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I
M;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`
M24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D[
M"F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O
M7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69]
M.PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("@D
M;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R
M8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F
M:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\
M)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY
M("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O
M(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*
M?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R
M97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F
M:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F
M;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I
M='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L
M("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA
M<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO
M;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD*
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D[
M"B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT
M9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^
M861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@
M/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?
M=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK
M("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F
M:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I
M9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M
M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`````````@/___\]!`1L#.^@````<````<'/__P0!
M``"P=___\`T``-!Z__\H`0``$*#__VP!``#`H/__T`$``$"A___T`0``4*/_
M_W0"``"PI/__+`,``!"F__^X`P``L*;__Q0$``!PI___L`0``*"G___8!```
M\*?__Q`%``"PJ/__G`4``,"H__^P!0``@*K__ZP&``"PJO__P`8``*"K__\@
M!P``8*W__U`'``#0K?__;`<```"N__^0!P``,*___P`(``!PN___W`L``$"_
M__]L#0``L+___[@-``#PO___,`X``##`__]0#@``H,#__XP.```4````````
M``%Z4@`!?`@!&PP$!(@!```@````'````&1R__]`!`````X(1@X,2@\+=`1X
M`#\:.RHR)")`````0````*!Y__\Q)0```$$."(4"00X,AP-##A"&!$$.%(,%
M1@Z@!@,;)0H.%$'##A!!Q@X,0<<."$'%#@1!"P```&````"$````G)[__Z8`
M````20X(A0)!#@R'`T$.$(8$00X4@P5##C`"1`XT00XX00X\00Y`2`XP5PH.
M%$/##A!!Q@X,0<<."$'%#@1%"UH.%$7##A!!Q@X,0<<."$'%#@0````@````
MZ````.B>__]R`````$$."(,"10X@`F4*#@A!PPX$00M\````#`$``$2?__\0
M`@```$$."(4"00X,AP-##A"&!$$.%(,%10Y,5PY02`Y`6@Y,00Y02`Y``DL.
M3$<.4$H.0`)L"@X40<,.$$'&#@Q!QPX(0<4.!$<+`DX.2$$.3$$.4$@.0&\.
M3$L.4$@.0$X.1$$.2$D.3$4.4$P.0````+0```",`0``U*#__U8!````00X(
MA0)!#@R'`T$.$(8$00X4@P5(#J`!;`H.%$'##A!!Q@X,0<<."$'%#@1$"T,.
MK`%!#K`!2`Z@`4\.K`%!#K`!2`Z@`5<.K`%$#K`!9`ZL`4$.J`%!#JP!00ZP
M`44.M`%"#K@!0@Z\`4$.P`%(#J0!10ZH`4$.K`%"#K`!2`Z@`5@.K`%!#K`!
M2`Z@`4,.K`%!#K`!2`Z@`78.K`%!#K`!4`Z@`0"(````1`(``'RA__]=`0``
M`$$."(8"00X,@P-##AQ&#B!,#AQ)#B!*#AQ&#B!9#AQ&#B!/#AQ&#B!(#A1"
M#AA%#AQ!#B!)#AQ&#B!/#AQ&#B!/#AQ&#B!,#AQ)#B!.#A!)#AQ&#B!.#A!&
M#AQ)#B!6#AQ&#B!6#AQ&#B!,#AQ)#B!1#@Q!PPX(0<8.!%@```#0`@``4*+_
M_YD`````00X(@P)%#AQ&#B!.#A1!#AA!#AQ"#B!(#A!'"@X(0\,.!$@+0PX<
M1@X@3@X03PX<1@X@3@X03PX80@X<00X@2`X02`X(1,,.!```F````"P#``"4
MHO__NP````!!#@B%`D$.#(<#0PX0A@1!#A2#!4@.M"!4#K@@10Z\($4.P"!(
M#K`@4PZT($$.N"!"#KP@00[`($@.L"!'#KP@1@[`($8.Q"!!#L@@00[,($$.
MT"!(#K`@5@H.%$'##A!!Q@X,0<<."$'%#@1%"TL.O"!&#L`@2`ZT($$.N"!!
M#KP@00[`($@.L"``)````,@#``"XHO__)P````!##AQ&#B!*#B1%#BA%#BQ!
M#C!(#@0``#0```#P`P``P*+__T0`````0PX<1@X@3@X<1@X@1@X<00X80@X<
M10X@10XD10XH10XL00XP2`X$B````"@$``#8HO__L0````!!#@B'`D$.#(8#
M00X0@P1&#J!`5PZH0$4.K$!!#K!`10ZT0$4.N$!"#KQ`10[`0$@.H$!'#J1`
M10ZH0$@.K$!!#K!`2`Z@0$P.K$!!#K!`2`Z@0$D.I$!!#JA`00ZL0$$.L$!,
M#J!`6`H.$$'##@Q!Q@X(0<<.!$0+```0````M`0```RC__\%`````````/@`
M``#(!```"*/__[P!````00X(A0)!#@R'`T$.$(8$00X4@P5&#L`@;@[(($0.
MS"!!#M`@2`[`(&P*#A1!PPX00<8.#$''#@A!Q0X$00M##LP@00[0($8.S"!!
M#L@@20[,($$.T"!(#L`@;`[(($$.S"!!#M`@2`[`($L.S"!!#M`@2`[`('`.
MQ"!!#L@@10[,($$.T"!%#M0@10[8($(.W"!!#N`@2`[,($8.T"!(#L0@1@[(
M($$.S"!"#M`@2`[`($<.S"!&#M`@3@[`($\.R"!%#LP@0@[0($@.P"!*#L@@
M0@[,($$.T"!(#L`@4P[,($$.T"!(#L`@`!````#$!0``S*/__R(`````````
M7````-@%``#HH___Z`````!!#@B#`D,.(%8.+$$.,$P.(`)$#BQ"#C!(#B!/
M"@X(0<,.!$L+80XD00XH00XL10XP2`X@2`H."$'##@1'"T,*#@A#PPX$00M+
M#@A!PPX$+````#@&``!XI/__MP$```!!#@B'`D$.#(8#0PY``UL!"@X,0<8.
M"$''#@1&"P``&````&@&```(IO__:0````!##B!F"@X$1PL``"````"$!@``
M7*;__R0`````0PX02`X<00X@2`X020H.!$,+`&P```"H!@``:*;__R8!````
M00X(A0)!#@R'`T8.$(8$00X4@P5(#F`"4@YH00YL00YP3`Y@`D(*#A1!PPX0
M0<8.#$''#@A!Q0X$20M##FQ!#G!L#F1%#FA%#FQ!#G!%#G1"#GA"#GQ!#H`!
M3`Y@``#8`P``&`<``"BG__\W#````$$."(4"00X,AP-!#A"&!$$.%(,%1@ZP
M@@("I@Z\@@)!#L""`DP.L(("0PZ\@@)!#L""`D@.L(("50Z\@@)$#L""`D4.
MQ(("0@[(@@)"#LR"`D$.T(("2PZP@@("0PZ\@@)!#L""`D@.L(("`D,.O(("
M00[`@@)(#K""`E8.O(("0P[`@@)(#K""`G,.O(("2@[`@@)*#L2"`D<.R(("
M10[,@@)!#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2`ZX@@)%#KR"`D$.P(("
M2`ZP@@)(#KR"`D8.P(("2`ZT@@)&#KB"`D0.O(("0@[`@@)(#K""`D<.O(("
M1`[`@@)&#L2"`D4.R(("0@[,@@)&#M""`D@.L(("7`H.%$'##A!!Q@X,0<<.
M"$'%#@1$"T\*#KB"`D$.O(("1`[`@@)&#L2"`D4.R(("20M##KR"`D8.P(("
M3@ZP@@)3#KR"`D8.P(("4PZP@@)+#KR"`D8.P(("3@ZP@@)3#KR"`D$.P(("
M6@ZP@@)+#KR"`D$.P(("1@Z\@@)!#KB"`D$.O(("1@[`@@)(#K""`DT.O(("
M00[`@@)(#K""`GP.N(("0@Z\@@)!#L""`DP.L(("8PZT@@)!#KB"`D4.O(("
M10[`@@)%#L2"`D(.R(("0@[,@@)%#M""`D@.L(("7@Z\@@)%#L""`D$.Q(("
M00[(@@)%#LR"`D$.T(("10[4@@)"#MB"`D(.W(("00[@@@)(#K""`D,.N(("
M10Z\@@)!#L""`D@.L(("2`Z\@@)$#L""`F`.L(("4@Z\@@)!#L""`E@.L(("
M=`Z\@@)!#L""`D@.L(("60ZT@@)"#KB"`D(.O(("10[`@@)(#K2"`D(.N(("
M2`Z\@@)!#L""`D@.L(("6@ZT@@)"#KB"`D(.O(("1`[`@@("E0ZP@@)&#K2"
M`D4.N(("2`Z\@@)$#L""`D@.L(("`HD.M(("00ZX@@)(#KR"`D$.P(("6`ZP
M@@("_PZT@@)!#KB"`D$.O(("2`[`@@)/#K""`G4.O(("1`[`@@("0@ZP@@(#
MWP$.O(("1`[`@@)%#L2"`D(.R(("0@[,@@)!#M""`DL.L(("40ZT@@)(#KB"
M`D4.O(("1`[`@@)%#L2"`D(.R(("0@[,@@)$#M""`D@.L(("5@Z\@@)!#L""
M`D@.L(("`QX!#K2"`D(.N(("0@Z\@@)%#L""`D@.M(("0@ZX@@)(#KR"`D$.
MP(("2@[$@@)(#LB"`D4.S(("1`[0@@)%#M2"`D(.V(("0@[<@@)$#N""`D@.
ML(("C`$``/0*``",K___S@,```!!#@B%`D$.#(<#00X0A@1!#A2#!4,./%(.
M0%H.,%4./$8.0$<.1$(.2$4.3$$.4$@.,'$..$$./$@.0$@.,%8./$8.0$<.
M1$$.2$$.3$$.4$@.,%@./$8.0$<.1$(.2$$.3$$.4$@.,%T./$8.0$<.1$(.
M2$4.3$$.4$@.,$P./$@.0$@.-$4..$$./$$.0$L.,$\./$8.0$<.1$(.2$4.
M3$$.4$@.,&0./$@.0$@.-$$..$$./$$.0$@.,$,./$8.0%H.,%(..$4./$$.
M0$L.,&(*#A1!PPX00<8.#$''#@A!Q0X$2PM3#CQ&#D!)#CQ!#CA!#CQ!#D!(
M#C!F#CQ&#D!(#C!Q#CA!#CQ!#D!-#C!7"@XT00XX1PX\10Y`2PM(#CQ-#D!1
M#C!(#CQ&#D!'#D1"#DA!#DQ!#E!(#C!%#CQ&#D!'#D1"#DA!#DQ!#E!(#C!(
M#CQ&#D!&#CQ!#CA!#CQ!#D!(#C!("@X\10Y`10M&#C1&#CA"#CQ%#D```$@`
M``"$#```S+'__VD`````00X(A@)!#@R#`T,.'$4.($L.$'`.&$4.'$$.($@.
M$$<*#@Q!PPX(0<8.!$$+0PX,0\,."$'&#@0````T````T`P``/"Q__\X````
M`$,.'$8.($8.'$$.&$(.'$$.($8.'$8.($@.%$(.&$4.'$$.($@.!#P````(
M#0``N&G__R("````1`P!`$<0!0)U`$4/`W5T!A`&`G5\$`,"=7@#HP$*P0P!
M`$'#0<9!Q4,,!`1!"P`<````2`T``+BQ__\Z`````$$."(,"3@X@:0X(0<,.
M!#@```!H#0``V+'__V$`````00X(A0)!#@R'`T,.$(8$00X4@P5.#C`"2`X4
M0<,.$$'&#@Q!QPX(0<4.!!````"D#0``#++__P(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#0F00(L)D$"``````!`````0````$````%`@``
M`0```%0"```,````=)($"`T```#4WP0(&0```/@^!0@;````!````!H```#\
M/@4('`````0```#U_O]OK($$"`4```"HB00(!@````B#!`@*````'04```L`
M```0````%0`````````#`````$`%"`(````8`@``%````!$````7````7)`$
M"!$````LD`0($@```#`````3````"````/[__V^<CP0(____;P(```#P__]O
MQHX$"```````````````````````````````````````````````````````
M```````````````$/P4(``````````"VD@0(QI($"-:2!`CFD@0(]I($"`:3
M!`@6DP0()I,$"#:3!`A&DP0(5I,$"&:3!`AVDP0(AI,$"):3!`BFDP0(MI,$
M",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4!`@VE`0(1I0$"%:4!`AFE`0(
M=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CVE`0(!I4$"!:5!`@F
ME00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5!`BVE00(QI4$"-:5
M!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&E@0(5I8$"&:6!`AVE@0(AI8$
M"):6!`BFE@0(MI8$",:6!`C6E@0(``````````#_____(.,$"$=#0SH@*%5B
M=6YT=2`T+CDN,2TQ.75B=6YT=3$I(#0N.2XQ`$=#0SH@*%5B=6YT=2`T+C@N
M,RTQ,75B=6YT=3$I(#0N."XS```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!
M0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y
M;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````
M```````````````````````````````````````````````````````+````
M`0````(```!4@00(5`$``!,```````````````$`````````$P````<````"
M````:($$"&@!```@```````````````$`````````"$````'`````@```(B!
M!`B(`0``)```````````````!``````````T````]O__;P(```"L@00(K`$`
M`%P!```%``````````0````$````/@````L````"````"(,$"`@#``"@!@``
M!@````$````$````$````$8````#`````@```*B)!`BH"0``'04`````````
M`````0````````!.````____;P(```#&C@0(Q@X``-0````%``````````(`
M```"````6P```/[__V\"````G(\$")P/``"0````!@````(````$````````
M`&H````)`````@```"R0!`@L$```,`````4`````````!`````@```!S````
M"0```$(```!<D`0(7!```!@"```%````#`````0````(````?`````$````&
M````=)($"'02```C```````````````$`````````'<````!````!@```*"2
M!`B@$@``0`0`````````````$`````0```""`````0````8```#@E@0(X!8`
M`/)(`````````````!``````````B`````$````&````U-\$"-1?```4````
M```````````$`````````(X````!`````@```.C?!`CH7P``2#\`````````
M````"`````````"6`````0````(````P'P4(,)\``.P```````````````0`
M````````I`````$````"````'"`%"!R@``"X#0`````````````$````````
M`*X````.`````P```/@^!0CXK@``!```````````````!`````````"Z````
M#P````,```#\/@4(_*X```0```````````````0`````````Q@````$````#
M`````#\%"`"O```$```````````````$`````````,L````&`````P````0_
M!0@$KP``^`````8`````````!`````@```#4`````0````,```#\/P4(_*\`
M``0```````````````0````$````V0````$````#`````$`%"`"P```8`0``
M```````````$````!````.(````!`````P```!A!!0@8L0``$```````````
M````!`````````#H````"`````,```!`004(*+$``%00`````````````$``
M````````[0````$````P`````````"BQ``!(```````````````!`````0``
I``$````#``````````````!PL0``]@```````````````0``````````
